def aitv(audio, png, output):
    
    import ffmpeg

    audio = ffmpeg.input(audio)
    png = ffmpeg.input(png)
    (
        ffmpeg
        .output(audio, png, output, format='mp4')
        .run()
    )


from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.2'
DESCRIPTION = 'A basic python script to merge an audio and an image into a video using ffmpeg.'

# Setting up
setup(
    name="aitv",
    version=VERSION,
    author="JustCow",
    author_email="<justcow@pm.me>",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=['ffmpeg-python'],
    keywords=['python', 'video', 'audio', 'justcow'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)